#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2010 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
"""
Level browser views.
"""
from zope.interface import implements
from zope.component import adapts, getMultiAdapter, getUtility
from zope.publisher.browser import BrowserView
from zope.app.intid.interfaces import IIntIds
from zope.app.pagetemplate.viewpagetemplatefile import ViewPageTemplateFile
from zope.traversing.browser.absoluteurl import absoluteURL

from schooltool.app.interfaces import ISchoolToolApplication
from schooltool.schoolyear.interfaces import ISchoolYear, ISchoolYearContainer
from schooltool.skin.containers import ContainerView
from schooltool.skin.skin import NavigationViewlet
from schooltool.relationship.relationship import getRelatedObjects
from schooltool.cambodia.app.skin import ISchoolToolCambodiaLayer
from schooltool.cambodia.grade.interfaces import ILevelContainer
from schooltool.cambodia.grade.level import URICourse, URILevelCourses
from schooltool.cambodia.grade.grade import URIGroup, URILevelGroups
from schooltool.cambodia.grade.grade import URISection, URISectionEnrollment


class LevelContainerAbsoluteURLAdapter(BrowserView):
    adapts(ILevelContainer, ISchoolToolCambodiaLayer)

    def __str__(self):
        container_id = int(self.context.__name__)
        int_ids = getUtility(IIntIds)
        container = int_ids.getObject(container_id)
        url = str(getMultiAdapter((container, self.request), name='absolute_url'))
        return url + '/cambodia-levels'

    __call__ = __str__


class LevelContainerView(BrowserView):
    """A Level Container view."""

    template = ViewPageTemplateFile('templates/levels.pt')

    def getCourseClasses(self, course):
        result = []
        for section in course.sections:
            groups = getRelatedObjects(
                section, URIGroup, rel_type=URISectionEnrollment)
            result.append({
                'section': section,
                'groups': groups,
                })
        return result

    def getLevelCourses(self, level):
        result = []
        courses = getRelatedObjects(
            level, URICourse, rel_type=URILevelCourses)
        # XXX: Sorting by title may be not the best option here
        courses = sorted(courses, key=lambda c: (c.title, c.__name__))
        for course in courses:
            result.append({
                'course': course,
                'classes': self.getCourseClasses(course),
                })
        return result

    def levels(self):
        levels = []
        for level in self.context.values():
            levels.append({
                'level': level,
                'courses': self.getLevelCourses(level),
                })

        for level in levels:
            level['max_classes'] = 0
            if level['courses']:
                level['max_classes'] = max(
                    [len(course['classes'])
                     for course in level['courses']])

        return levels


class ManageLevelViewlet(NavigationViewlet):
    @property
    def link(self):
        app = ISchoolToolApplication(None)
        syc = ISchoolYearContainer(app)
        active_schoolyear = syc.getActiveSchoolYear()
        if active_schoolyear is None:
            return ''
        levels = ILevelContainer(active_schoolyear)
        return absoluteURL(levels, self.request)
