#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2005 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
"""
Gradebook customizations for schooltool.cambodia
"""

from decimal import Decimal

from zope.component import adapts
from zope.interface import implements

from schooltool.course.interfaces import ISection
from schooltool.schoolyear.interfaces import ISubscriber
from schooltool.schoolyear.subscriber import EventAdapterSubscriber
from schooltool.gradebook.activity import Worksheet, Activity
from schooltool.gradebook.activity import LinkedColumnActivity
from schooltool.gradebook.activity import createSourceString
from schooltool.gradebook.interfaces import IActivities
from schooltool.requirement.scoresystem import RangedValuesScoreSystem
from schooltool.cambodia.grade.grade import CambodiaSectionCreatedEvent

from schooltool.cambodia import CambodiaMessage as _


class SetUpCambodiaSectionGradebook(EventAdapterSubscriber):
    adapts(CambodiaSectionCreatedEvent)
    implements(ISubscriber)

    def __call__(self):
        """Deploy the report sheet to the newly added section."""

        section = self.event.section

        credits = list(section.courses)[0].credits
        if not credits:
            credits = 100

        activities = IActivities(section)
        worksheet1 = Worksheet(_('Semester 1'))
        worksheet2 = Worksheet(_('Semester 2'))
        worksheet3 = Worksheet(_('Final Average'))
        activities['1'] = worksheet1
        activities['2'] = worksheet2
        activities['3'] = worksheet3

        worksheet1.setCategoryWeight('assignment', Decimal('0.50'))
        worksheet1.setCategoryWeight('exam', Decimal('0.50'))
        worksheet2.setCategoryWeight('assignment', Decimal('0.50'))
        worksheet2.setCategoryWeight('exam', Decimal('0.50'))

        scoresystem = RangedValuesScoreSystem(u'generated',  min=0, max=int(credits))
        sem1_list = [
            (_('Oct'), _('October'), ''),
            (_('Nov'), _('November'), ''),
            (_('Dec'), _('December'), ''),
            (_('Jan'), _('January'), ''),
            (_('S1 Exam'), _('Semester 1 Exam'), _('S1 Ex')),
            ]
        sem2_list = [
            (_('Mar'), _('March'), ''),
            (_('April'), _('April'), ''),
            (_('May'), _('May'), ''),
            (_('June'), _('June'), ''),
            (_('S2 Exam'), _('Semester 2 Exam'), _('S2 Ex')),
            ]

        for index, (title, description, label) in enumerate(sem1_list):
            if 'Exam' in title:
                category = 'exam'
            else:
                category = 'assignment'
            activity = Activity(title, category, scoresystem, description, label)
            worksheet1[str(index + 1)] = activity

        for index, (title, description, label) in enumerate(sem2_list):
            if 'Exam' in title:
                category = 'exam'
            else:
                category = 'assignment'
            activity = Activity(title, category, scoresystem, description, label)
            worksheet2[u'%d' % (index + 1)] = activity

        source1 = createSourceString(worksheet1)
        worksheet3['1'] = LinkedColumnActivity(_('S1 Average'), '', _('S1'),
            source1)
        source2 = createSourceString(worksheet2)
        worksheet3['2'] = LinkedColumnActivity(_('S2 Average'), '', _('S2'),
            source2)

